==> FIESTA_3.6.4.tar.gz: FIESTA/tests/testthat/_snaps/modGBtree.md <==
# modGBtree Testing

    Code
      modGBtree_TPA_est
    Output
                                      Forest type     Estimate Percent Sampling Error
      1                    Rocky Mountain juniper   94791336.1                  24.57
      2                          Juniper woodland     54049570                  28.36
      3                 Pinyon / juniper woodland    1072754.3                    100
      4                               Douglas-fir  240480740.8                  21.25
      5                            Ponderosa pine  260800542.8                  17.27
      6                          Engelmann spruce    201830027                  25.03
      7          Engelmann spruce / subalpine fir  906992126.3                   12.9
      8                             Subalpine fir  515593644.5                   17.5
      9                               Blue spruce    6141035.5                 101.99
      10                           Lodgepole pine 1562955034.4                  11.66
      11                              Limber pine   24830388.9                  44.88
      12                           Whitebark pine  135110827.9                  28.26
      13                                  Bur oak   33070990.5                   66.4
      14                 Elm / ash / black locust       116070                 107.34
      15                               Cottonwood      9712948                     51
      16 Sugarberry / hackberry / elm / green ash    1020021.8                    100
      17                                    Aspen  256138904.4                  20.59
      18                               Nonstocked   14487669.1                  33.12
      19                                    Total 4319194632.3                   4.83

---

    Code
      modGBtree_VOL_est
    Output
                                      Forest type      Estimate
      1                    Rocky Mountain juniper   103705329.9
      2                          Juniper woodland     7591934.5
      3                 Pinyon / juniper woodland            --
      4                               Douglas-fir  1279391473.1
      5                            Ponderosa pine    1134539402
      6                          Engelmann spruce  1318783735.9
      7          Engelmann spruce / subalpine fir  3197965334.6
      8                             Subalpine fir  1543226579.4
      9                               Blue spruce    54704348.4
      10                           Lodgepole pine  3899090965.5
      11                              Limber pine    52426047.4
      12                           Whitebark pine   242115077.6
      13                                  Bur oak    32834363.6
      14                 Elm / ash / black locust     2578979.3
      15                               Cottonwood   169546392.1
      16 Sugarberry / hackberry / elm / green ash     4455857.7
      17                                    Aspen   420518373.4
      18                               Nonstocked    53104873.9
      19                                    Total 13516579068.4
         Percent Sampling Error
      1                   42.43
      2                   86.68
      3                      --
      4                   20.05
      5                   15.44
      6                    27.1
      7                   12.53
      8                   16.43
      9                  101.99
      10                  10.64
      11                  49.94
      12                   27.2
      13                  63.49
      14                 107.34
      15                  58.21
      16                    100
      17                  27.81
      18                  42.69
      19                    4.7

---

    Code
      modGBtree_BA_est
    Output
                                      Forest type    Estimate Percent Sampling Error
      1                    Rocky Mountain juniper  31091988.8                  20.84
      2                          Juniper woodland  44551680.3                  27.95
      3                 Pinyon / juniper woodland   1392341.4                    100
      4                               Douglas-fir  69947672.6                  17.32
      5                            Ponderosa pine  70356423.2                   14.2
      6                          Engelmann spruce  58730163.7                  23.77
      7          Engelmann spruce / subalpine fir 164160289.4                  11.55
      8                             Subalpine fir  86116217.3                  15.59
      9                               Blue spruce   2138790.9                 101.99
      10                           Lodgepole pine 223510197.5                   9.45
      11                              Limber pine   5301324.5                  41.19
      12                           Whitebark pine  22334274.9                   26.5
      13                                  Bur oak   4111665.6                  53.45
      14                 Elm / ash / black locust      134940                 107.34
      15                               Cottonwood   9086477.2                  54.45
      16 Sugarberry / hackberry / elm / green ash    421419.2                    100
      17                                    Aspen  32132910.2                  22.25
      18                               Nonstocked   3886012.5                  29.31
      19                                    Total   829404789                   3.78

==> FIESTA_3.7.0.tar.gz: FIESTA/tests/testthat/_snaps/modGBtree.md <==
# modGBtree Testing

    Code
      modGBtree_TPA_est
    Output
                                      Forest type     Estimate Percent Sampling Error
      1                    Rocky Mountain juniper   94791336.1                  24.57
      2                          Juniper woodland     54049570                  28.36
      3                 Pinyon / juniper woodland    1072754.3                    100
      4                               Douglas-fir  240480740.8                  21.25
      5                            Ponderosa pine  260800542.8                  17.27
      6                          Engelmann spruce    201830027                  25.03
      7          Engelmann spruce / subalpine fir  906992126.3                   12.9
      8                             Subalpine fir  515593644.5                   17.5
      9                               Blue spruce    6141035.5                 101.99
      10                           Lodgepole pine 1562955034.4                  11.66
      11                              Limber pine   24830388.9                  44.88
      12                           Whitebark pine  135110827.9                  28.26
      13                                  Bur oak   33070990.5                   66.4
      14                 Elm / ash / black locust       116070                 107.34
      15                               Cottonwood      9712948                     51
      16 Sugarberry / hackberry / elm / green ash    1020021.8                    100
      17                                    Aspen  256138904.4                  20.59
      18                               Nonstocked   14487669.1                  33.12
      19                                    Other           --                     --
      20                                    Total 4319194632.3                   4.83

---

    Code
      modGBtree_VOL_est
    Output
                                      Forest type      Estimate
      1                    Rocky Mountain juniper   103705329.9
      2                          Juniper woodland     7591934.5
      3                 Pinyon / juniper woodland            --
      4                               Douglas-fir  1279391473.1
      5                            Ponderosa pine    1134539402
      6                          Engelmann spruce  1318783735.9
      7          Engelmann spruce / subalpine fir  3197965334.6
      8                             Subalpine fir  1543226579.4
      9                               Blue spruce    54704348.4
      10                           Lodgepole pine  3899090965.5
      11                              Limber pine    52426047.4
      12                           Whitebark pine   242115077.6
      13                                  Bur oak    32834363.6
      14                 Elm / ash / black locust     2578979.3
      15                               Cottonwood   169546392.1
      16 Sugarberry / hackberry / elm / green ash     4455857.7
      17                                    Aspen   420518373.4
      18                               Nonstocked    53104873.9
      19                                    Other            --
      20                                    Total 13516579068.4
         Percent Sampling Error
      1                   42.43
      2                   86.68
      3                      --
      4                   20.05
      5                   15.44
      6                    27.1
      7                   12.53
      8                   16.43
      9                  101.99
      10                  10.64
      11                  49.94
      12                   27.2
      13                  63.49
      14                 107.34
      15                  58.21
      16                    100
      17                  27.81
      18                  42.69
      19                     --
      20                    4.7
